@@ -369,3 +369,52 @@ def make_update_string_v2(payload, table, key, key_value):
     print("UPDATE STRING: " + update_string)
 
     return update_string
+
+
+def make_insert_string_v3(payload: dict, table: str):
+
+    _keys = "{}".format("".join("{}, ".format(e) for e in list(payload.keys())))[:-2]
+    _values = ""
+
+    _val = []
+    for _v in payload.values():
+
+        if isinstance(_v, str):
+            _val.append(_v.replace("'", "''"))
+
+        elif isinstance(_v, int):
+            _val.append(_v)
+
+        elif isinstance(_v, dict):
+
+            if not _v:
+                _val.append("'{}'")
+
+            else:
+                _v = json.dumps(_v)
+                _v = _v.replace("'", "''")
+                _val.append(json.dumps(_v).replace('"{', "{").replace('}"', "}").replace("\\", ""))
+
+        elif isinstance(_v, list):
+            if not _v:
+                _val.append("{}")
+            else:
+                _val.append(str(_v).replace("'", '"').replace("[", "{").replace("]", "}"))
+
+        elif isinstance(_v, bool):
+            _val.append("{}".format(_v))
+
+        elif not _v:
+            _val.append("NULL")
+
+        else:
+            raise ValueError("Unsupported value type: '{}'".format(type(_v)))
+
+    _values = "{}".format("".join("'{}', ".format(e) for e in list(_val)))[:-2].replace("'NULL'", "NULL")
+
+    _query = "INSERT INTO {table} ({keys}) VALUES ({values}) ON CONFLICT (campaign_id) DO NOTHING".format(
+        table=table,
+        keys=_keys,
+        values=_values)
+
+    return _query
\ No newline at end of file
